[gimp/gtk3-port: 1/226] Switch to version 3.0 in a lot of places and depend on GTK+ 3.2



commit 2f2978564cdd7c290bb48b5e6d2972ce9b4b9e03
Author: Michael Natterer <mitch gimp org>
Date:   Fri Oct 15 09:56:27 2010 +0200

    Switch to version 3.0 in a lot of places and depend on GTK+ 3.2
    
    and lots of other newer libraries.

 .gitignore                      |    6 ++--
 app/Makefile.am                 |   16 ++++++------
 app/config/gimpconfig-dump.c    |   12 ++++----
 app/gui/gui.c                   |    6 ++--
 configure.ac                    |   52 ++++++++++++++------------------------
 docs/.gitignore                 |    6 ++--
 docs/gimp.1.in                  |   10 +++---
 docs/gimprc.5.in                |    8 +++---
 etc/gimprc                      |    4 +-
 libgimp/Makefile.am             |   42 +++++++++++++++---------------
 libgimpbase/Makefile.am         |   10 +++---
 libgimpbase/gimpenv.c           |   32 ++++++++++++------------
 libgimpcolor/Makefile.am        |   10 +++---
 libgimpconfig/Makefile.am       |   10 +++---
 libgimpmath/Makefile.am         |   10 +++---
 libgimpmodule/Makefile.am       |   10 +++---
 libgimpthumb/Makefile.am        |    8 +++---
 libgimpwidgets/Makefile.am      |   22 ++++++++--------
 libgimpwidgets/gimp3migration.c |    5 +++
 libgimpwidgets/gimp3migration.h |    4 +++
 tools/.gitignore                |    4 +-
 tools/Makefile.am               |    6 ++--
 22 files changed, 144 insertions(+), 149 deletions(-)
---
diff --git a/.gitignore b/.gitignore
index c5269c3..18fa6af 100644
--- a/.gitignore
+++ b/.gitignore
@@ -25,10 +25,10 @@
 /cscope.files
 /cscope.out
 /depcomp
-/gimp-2.0.pc
+/gimp-3.0.pc
 /gimp-zip
-/gimpthumb-2.0.pc
-/gimpui-2.0.pc
+/gimpthumb-3.0.pc
+/gimpui-3.0.pc
 /gtk-doc.make
 /install-sh
 /intltool-extract
diff --git a/app/Makefile.am b/app/Makefile.am
index 09a2209..6f8616a 100644
--- a/app/Makefile.am
+++ b/app/Makefile.am
@@ -40,9 +40,9 @@ SUBDIRS = \
 noinst_LIBRARIES = libapp.a
 
 if ENABLE_GIMP_CONSOLE
-bin_PROGRAMS = gimp-2.7 gimp-console-2.7
+bin_PROGRAMS = gimp-2.99 gimp-console-2.99
 else
-bin_PROGRAMS = gimp-2.7
+bin_PROGRAMS = gimp-2.99
 endif
 
 libapp_sources = \
@@ -86,7 +86,7 @@ $(srcdir)/version.c: git-version.h
 
 libapp_a_SOURCES = $(libapp_sources) $(libapp_generated_sources)
 
-gimp_2_7_SOURCES = $(libapp_sources) main.c
+gimp_2_99_SOURCES = $(libapp_sources) main.c
 
 
 if OS_WIN32
@@ -180,9 +180,9 @@ gimpconsoleldadd = \
 	$(INTLLIBS)			\
 	$(RT_LIBS)
 
-gimp_2_7_LDFLAGS = $(AM_LDFLAGS) $(win32_ldflags)
+gimp_2_99_LDFLAGS = $(AM_LDFLAGS) $(win32_ldflags)
 
-gimp_2_7_LDADD = \
+gimp_2_99_LDADD = \
 	gui/libappgui.a		\
 	menus/libappmenus.a	\
 	actions/libappactions.a	\
@@ -199,13 +199,13 @@ gimp_2_7_LDADD = \
 
 if ENABLE_GIMP_CONSOLE
 
-gimp_console_2_7_SOURCES = $(libapp_sources) main.c
+gimp_console_2_99_SOURCES = $(libapp_sources) main.c
 
-gimp_console_2_7_CPPFLAGS = \
+gimp_console_2_99_CPPFLAGS = \
 	$(AM_CPPFLAGS)			\
 	-DGIMP_CONSOLE_COMPILATION
 
-gimp_console_2_7_LDADD = \
+gimp_console_2_99_LDADD = \
 	$(gimpconsoleldadd) \
 	$(GIMPCONSOLERC)
 
diff --git a/app/config/gimpconfig-dump.c b/app/config/gimpconfig-dump.c
index 5cf410a..531e804 100644
--- a/app/config/gimpconfig-dump.c
+++ b/app/config/gimpconfig-dump.c
@@ -105,8 +105,8 @@ static const gchar system_gimprc_header[] =
 "documents the default values and shows what changes are possible.\n"
 "\n"
 "The variable ${gimp_dir} is set to the value of the environment "
-"variable GIMP2_DIRECTORY or, if that is not set, the compiled-in "
-"default value is used.  If GIMP2_DIRECTORY is not an absolute path, "
+"variable GIMP3_DIRECTORY or, if that is not set, the compiled-in "
+"default value is used.  If GIMP3_DIRECTORY is not an absolute path, "
 "it is interpreted relative to your home directory.";
 
 static void
@@ -209,21 +209,21 @@ static const gchar *man_page_path =
 ".TP\n"
 ".I gimp_dir\n"
 "The personal gimp directory which is set to the value of the environment\n"
-"variable GIMP2_DIRECTORY or to ~/@gimpdir  \n"
+"variable GIMP3_DIRECTORY or to ~/@gimpdir  \n"
 ".TP\n"
 ".I gimp_data_dir\n"
 "Base for paths to shareable data, which is set to the value of the\n"
-"environment variable GIMP2_DATADIR or to the compiled-in default value\n"
+"environment variable GIMP3_DATADIR or to the compiled-in default value\n"
 "@gimpdatadir  \n"
 ".TP\n"
 ".I gimp_plug_in_dir\n"
 "Base to paths for architecture-specific plugins and modules, which is set\n"
-"to the value of the environment variable GIMP2_PLUGINDIR or to the\n"
+"to the value of the environment variable GIMP3_PLUGINDIR or to the\n"
 "compiled-in default value @gimpplugindir  \n"
 ".TP\n"
 ".I gimp_sysconf_dir\n"
 "Path to configuration files, which is set to the value of the environment\n"
-"variable GIMP2_SYSCONFDIR or to the compiled-in default value \n"
+"variable GIMP3_SYSCONFDIR or to the compiled-in default value \n"
 "@gimpsysconfdir  \n"
 "\n";
 
diff --git a/app/gui/gui.c b/app/gui/gui.c
index f359bc9..f0264c8 100644
--- a/app/gui/gui.c
+++ b/app/gui/gui.c
@@ -250,9 +250,9 @@ gui_init (Gimp     *gimp,
 static gchar *
 gui_sanity_check (void)
 {
-#define GTK_REQUIRED_MAJOR 2
-#define GTK_REQUIRED_MINOR 24
-#define GTK_REQUIRED_MICRO 7
+#define GTK_REQUIRED_MAJOR 3
+#define GTK_REQUIRED_MINOR 2
+#define GTK_REQUIRED_MICRO 0
 
   const gchar *mismatch = gtk_check_version (GTK_REQUIRED_MAJOR,
                                              GTK_REQUIRED_MINOR,
diff --git a/configure.ac b/configure.ac
index 59332f7..e6b319f 100644
--- a/configure.ac
+++ b/configure.ac
@@ -7,8 +7,8 @@ AC_PREREQ(2.54)
 #   GIMP_INTERFACE_AGE += 1;
 
 m4_define([gimp_major_version], [2])
-m4_define([gimp_minor_version], [7])
-m4_define([gimp_micro_version], [5])
+m4_define([gimp_minor_version], [99])
+m4_define([gimp_micro_version], [0])
 m4_define([gimp_real_version],
           [gimp_major_version.gimp_minor_version.gimp_micro_version])
 m4_define([gimp_version], [gimp_real_version])
@@ -17,20 +17,20 @@ m4_define([gimp_binary_age],
           [m4_eval(100 * gimp_minor_version + gimp_micro_version)])
 
 # For overriding the version string. Comment out if not needed.
-# m4_define([gimp_version], [2.7.0])
+# m4_define([gimp_version], [3.0.0])
 
 # This is the X.Y used in -lgimp-X.Y
-m4_define([gimp_api_version], [2.0])
+m4_define([gimp_api_version], [3.0])
 
 # Versions used for apps, plugins, tools, pkg-config files, and data,
 # as well as global and user prefs
-m4_define([gimp_app_version], [2.7])
-m4_define([gimp_plugin_version], [2.0])
-m4_define([gimp_tool_version], [2.0])
-m4_define([gimp_pkgconfig_version], [2.0])
-m4_define([gimp_data_version], [2.0])
-m4_define([gimp_sysconf_version], [2.0])
-m4_define([gimp_user_version], [2.7])
+m4_define([gimp_app_version], [3.0])
+m4_define([gimp_plugin_version], [3.0])
+m4_define([gimp_tool_version], [3.0])
+m4_define([gimp_pkgconfig_version], [3.0])
+m4_define([gimp_data_version], [3.0])
+m4_define([gimp_sysconf_version], [3.0])
+m4_define([gimp_user_version], [3.0])
 
 m4_define([gimp_unstable],
           m4_if(m4_eval(gimp_minor_version % 2), [1], [yes], [no]))
@@ -44,7 +44,7 @@ m4_define([babl_required_version], [0.1.6])
 m4_define([gegl_required_version], [0.1.8])
 m4_define([glib_required_version], [2.30.2])
 m4_define([atk_required_version], [2.0.1])
-m4_define([gtk_required_version], [2.24.7])
+m4_define([gtk_required_version], [3.2.1])
 m4_define([gdk_pixbuf_required_version], [2.24.0])
 m4_define([cairo_required_version], [1.10.2])
 m4_define([cairo_pdf_required_version], [1.10.2])
@@ -147,7 +147,7 @@ AC_SUBST(LT_CURRENT_MINUS_AGE)
 
 
 # gettext i18n support
-GETTEXT_PACKAGE=gimp20
+GETTEXT_PACKAGE=gimp30
 AC_SUBST(GETTEXT_PACKAGE)
 AC_DEFINE_UNQUOTED(GETTEXT_PACKAGE, "$GETTEXT_PACKAGE",
                    [The prefix for our gettext translation domains.])
@@ -510,20 +510,10 @@ LIBS=$gimp_save_LIBS
 
 AC_PATH_XTRA
 
-AM_PATH_GTK_2_0(gtk_required_version, :,
+AM_PATH_GTK_3_0(gtk_required_version, :,
   AC_MSG_ERROR(Test for GTK+ failed. See the file 'INSTALL' for help.),
   gthread)
 
-# GTK+ 2.26.0 will never be released, we keep the check around anyway
-# because we will need it again after the switch to GTK+ 3.x
-AC_MSG_CHECKING([if GTK+ is version 2.26.0 or newer (bogus placeholder check)])
-if $PKG_CONFIG --atleast-version=2.26.0 gtk+-2.0; then
-  have_gtk_2_26=yes
-else
-  have_gtk_2_26=no
-fi
-AC_MSG_RESULT($have_gtk_2_26)
-
 PKG_CHECK_MODULES(GDK_PIXBUF, gdk-pixbuf-2.0 >= gdk_pixbuf_required_version)
 
 AC_PATH_PROG(GDK_PIXBUF_CSOURCE, gdk-pixbuf-csource, no)
@@ -962,7 +952,7 @@ fi
 ################################
 
 # Check if building for GTK+-X11
-gdk_target=`$PKG_CONFIG --variable=target gtk+-2.0`
+gdk_target=`$PKG_CONFIG --variable=target gtk+-3.0`
 
 have_libxmu="no (building for $gdk_target)"
 
@@ -1317,15 +1307,15 @@ AC_SUBST(FILE_XPM)
 AC_SUBST(XPM_LIBS)
 
 
-##################
-# Check for webkit
-##################
+#####################
+# Check for webkitgtk
+#####################
 
 AC_ARG_WITH(webkit, [  --without-webkit        don't build the help-browser plug-in])
 
 have_webkit=no
 if test "x$with_webkit" != xno; then
-  PKG_CHECK_MODULES(WEBKIT, webkit-1.0 >= webkit_required_version,
+  PKG_CHECK_MODULES(WEBKIT, webkitgtk-3.0 >= webkitgtk_required_version,
     WEB_PAGE='web-page$(EXEEXT)'
     have_webkit=yes,
     have_webkit="no (WebKit not found)")
@@ -2001,10 +1991,6 @@ if test "x$have_glib_2_31" != "xyes"; then
   CPPFLAGS="${CPPFLAGS} -DG_DISABLE_DEPRECATED"
 fi
 
-if test "x$have_gtk_2_26" != "xyes"; then
-  CPPFLAGS="${CPPFLAGS} -DGDK_DISABLE_DEPRECATED -DGTK_DISABLE_DEPRECATED"
-fi
-
 if test "x$have_gdk_pixbuf_2_26" != "xyes"; then
   CPPFLAGS="${CPPFLAGS} -DGDK_PIXBUF_DISABLE_DEPRECATED"
 fi
diff --git a/docs/.gitignore b/docs/.gitignore
index 3292440..2945135 100644
--- a/docs/.gitignore
+++ b/docs/.gitignore
@@ -1,7 +1,7 @@
 /Makefile
 /Makefile.in
-/gimp-2.*.1
-/gimprc-2.*.5
-/gimptool-2.0.1
+/gimp-3.*.1
+/gimprc-3.*.5
+/gimptool-3.0.1
 /Wilber.xcf
 /Wilber_Construction_Kit.xcf
diff --git a/docs/gimp.1.in b/docs/gimp.1.in
index 64bb37a..85411be 100644
--- a/docs/gimp.1.in
+++ b/docs/gimp.1.in
@@ -151,24 +151,24 @@ GIMP respects a number of environment variables.
 .B DISPLAY
 to get the default host and display number.
 .TP 8
-.B GIMP2_DIRECTORY
+.B GIMP3_DIRECTORY
 to get the name of the personal GIMP directory. If unset @gimpdir@ is
 used.  If this is an absolute path, it is used as is.  If it is a
 relative path, it is taken to be a subdirectory of the home directory.
 .TP 8
-.B GIMP2_DATADIR
+.B GIMP3_DATADIR
 to get the base location for data files such as brushes and patterns.
 If unset @gimpdatadir@ is used.
 .TP 8
-.B GIMP2_LOCALEDIR
+.B GIMP3_LOCALEDIR
 to get the base location for translations. If unset @gimplocaledir@
 is used.
 .TP 8
-.B GIMP2_PLUGINDIR
+.B GIMP3_PLUGINDIR
 to get the base location for plug-ins and modules. If unset
 @gimpplugindir@ is used.
 .TP 8
-.B GIMP2_SYSCONFDIR
+.B GIMP3_SYSCONFDIR
 to get the location of configuration files. If unset @gimpsysconfdir@
 is used.
 
diff --git a/docs/gimprc.5.in b/docs/gimprc.5.in
index 16559eb..0b0711e 100644
--- a/docs/gimprc.5.in
+++ b/docs/gimprc.5.in
@@ -918,21 +918,21 @@ There are a few variables that are pre-defined:
 .TP
 .I gimp_dir
 The personal gimp directory which is set to the value of the environment
-variable GIMP2_DIRECTORY or to ~/@gimpdir  
+variable GIMP3_DIRECTORY or to ~/@gimpdir  
 .TP
 .I gimp_data_dir
 Base for paths to shareable data, which is set to the value of the
-environment variable GIMP2_DATADIR or to the compiled-in default value
+environment variable GIMP3_DATADIR or to the compiled-in default value
 @gimpdatadir  
 .TP
 .I gimp_plug_in_dir
 Base to paths for architecture-specific plugins and modules, which is set
-to the value of the environment variable GIMP2_PLUGINDIR or to the
+to the value of the environment variable GIMP3_PLUGINDIR or to the
 compiled-in default value @gimpplugindir  
 .TP
 .I gimp_sysconf_dir
 Path to configuration files, which is set to the value of the environment
-variable GIMP2_SYSCONFDIR or to the compiled-in default value 
+variable GIMP3_SYSCONFDIR or to the compiled-in default value 
 @gimpsysconfdir  
 
 .SH FILES
diff --git a/etc/gimprc b/etc/gimprc
index d35f004..7c88804 100644
--- a/etc/gimprc
+++ b/etc/gimprc
@@ -8,8 +8,8 @@
 # documents the default values and shows what changes are possible.
 # 
 # The variable ${gimp_dir} is set to the value of the environment variable
-# GIMP2_DIRECTORY or, if that is not set, the compiled-in default value is
-# used.  If GIMP2_DIRECTORY is not an absolute path, it is interpreted
+# GIMP3_DIRECTORY or, if that is not set, the compiled-in default value is
+# used.  If GIMP3_DIRECTORY is not an absolute path, it is interpreted
 # relative to your home directory.
 
 # Sets the folder for temporary storage. Files will appear here during the
diff --git a/libgimp/Makefile.am b/libgimp/Makefile.am
index 6e72896..28fba91 100644
--- a/libgimp/Makefile.am
+++ b/libgimp/Makefile.am
@@ -66,7 +66,7 @@ INCLUDES = \
 	$(GTK_CFLAGS)	\
 	-I$(includedir)
 
-lib_LTLIBRARIES = libgimp-2.0.la libgimpui-2.0.la
+lib_LTLIBRARIES = libgimp-3.0.la libgimpui-3.0.la
 
 PDB_WRAPPERS_C = \
 	gimp_pdb.c			\
@@ -173,7 +173,7 @@ PDB_WRAPPERS_H = \
 	gimpunit_pdb.h			\
 	gimpvectors_pdb.h
 
-libgimp_2_0_la_sources = \
+libgimp_3_0_la_sources = \
 	gimp.c			\
 	gimp.h			\
 	gimpcompat.h		\
@@ -236,16 +236,16 @@ libgimp_2_0_la_sources = \
 	stdplugins-intl.h	\
 	libgimp-intl.h
 
-libgimp_2_0_la_built_sources = \
+libgimp_3_0_la_built_sources = \
 	gimpenums.c
 
-libgimp_2_0_la_extra_sources = gimpenums.c.tail
+libgimp_3_0_la_extra_sources = gimpenums.c.tail
 
-libgimp_2_0_la_SOURCES = \
-	$(libgimp_2_0_la_built_sources)	\
-	$(libgimp_2_0_la_sources)
+libgimp_3_0_la_SOURCES = \
+	$(libgimp_3_0_la_built_sources)	\
+	$(libgimp_3_0_la_sources)
 
-libgimpui_2_0_la_sources = \
+libgimpui_3_0_la_sources = \
 	gimpui.c			\
 	gimpui.h			\
 	gimpuitypes.h			\
@@ -292,15 +292,15 @@ libgimpui_2_0_la_sources = \
 	gimpzoompreview.c		\
 	gimpzoompreview.h
 
-libgimpui_2_0_la_built_sources = \
+libgimpui_3_0_la_built_sources = \
 	gimpuimarshal.c			\
 	gimpuimarshal.h
 
-libgimpui_2_0_la_extra_sources = gimpuimarshal.list
+libgimpui_3_0_la_extra_sources = gimpuimarshal.list
 
-libgimpui_2_0_la_SOURCES = \
-	$(libgimpui_2_0_la_built_sources)	\
-	$(libgimpui_2_0_la_sources)
+libgimpui_3_0_la_SOURCES = \
+	$(libgimpui_3_0_la_built_sources)	\
+	$(libgimpui_3_0_la_sources)
 
 gimpinclude_HEADERS = \
 	gimp.h				\
@@ -358,12 +358,12 @@ gimpinclude_HEADERS = \
 	gimpselectbutton.h		\
 	gimpzoompreview.h
 
-libgimp_2_0_la_LDFLAGS = \
+libgimp_3_0_la_LDFLAGS = \
 	-version-info $(LT_VERSION_INFO)	\
 	$(no_undefined)				\
 	$(libgimp_export_symbols)
 
-libgimp_2_0_la_LIBADD = \
+libgimp_3_0_la_LIBADD = \
 	$(libgimpconfig)	\
 	$(libgimpcolor)		\
 	$(libgimpbase)		\
@@ -371,18 +371,18 @@ libgimp_2_0_la_LIBADD = \
 	$(GDK_PIXBUF_LIBS)	\
 	$(RT_LIBS)
 
-libgimp_2_0_la_DEPENDENCIES = \
+libgimp_3_0_la_DEPENDENCIES = \
 	$(gimp_def)		\
 	$(libgimpconfig)	\
 	$(libgimpcolor)		\
 	$(libgimpbase)
 
-libgimpui_2_0_la_LDFLAGS = \
+libgimpui_3_0_la_LDFLAGS = \
 	-version-info $(LT_VERSION_INFO)	\
 	$(no_undefined)				\
 	$(libgimpui_export_symbols)
 
-libgimpui_2_0_la_LIBADD = \
+libgimpui_3_0_la_LIBADD = \
 	$(libgimp)		\
 	$(libgimpwidgets)	\
 	$(libgimpcolor)		\
@@ -391,7 +391,7 @@ libgimpui_2_0_la_LIBADD = \
 	$(GTK_LIBS)		\
 	$(RT_LIBS)
 
-libgimpui_2_0_la_DEPENDENCIES = \
+libgimpui_3_0_la_DEPENDENCIES = \
 	$(gimpui_def)		\
 	$(libgimp)		\
 	$(libgimpwidgets)	\
@@ -401,8 +401,8 @@ EXTRA_DIST = \
 	COPYING				\
 	gimp.def			\
 	gimpui.def			\
-	$(libgimp_2_0_la_extra_sources)	\
-	$(libgimpui_2_0_la_extra_sources)
+	$(libgimp_3_0_la_extra_sources)	\
+	$(libgimpui_3_0_la_extra_sources)
 
 install-data-local: install-ms-lib install-libtool-import-lib
 
diff --git a/libgimpbase/Makefile.am b/libgimpbase/Makefile.am
index 89a81c0..1cfeb78 100644
--- a/libgimpbase/Makefile.am
+++ b/libgimpbase/Makefile.am
@@ -67,7 +67,7 @@ INCLUDES = \
 EXTRA_DIST = \
 	gimpbase.def
 
-lib_LTLIBRARIES = libgimpbase-2.0.la
+lib_LTLIBRARIES = libgimpbase-3.0.la
 
 # help `make' along by giving another name for the file, which it knows
 # how to build
@@ -119,7 +119,7 @@ libgimpbase_sources = \
 libgimpbase_built_sources = \
 	gimpbaseenums.c
 
-libgimpbase_2_0_la_SOURCES = $(libgimpbase_sources) $(libgimpbase_built_sources)
+libgimpbase_3_0_la_SOURCES = $(libgimpbase_sources) $(libgimpbase_built_sources)
 
 
 libgimpbaseinclude_HEADERS = \
@@ -143,15 +143,15 @@ libgimpbaseinclude_HEADERS = \
 	gimputils.h
 
 
-libgimpbase_2_0_la_LDFLAGS = \
+libgimpbase_3_0_la_LDFLAGS = \
 	-version-info $(LT_VERSION_INFO)	\
 	$(no_undefined) 			\
 	$(libgimpbase_export_symbols)		\
 	$(CARBON_LDFLAGS)
 
-libgimpbase_2_0_la_DEPENDENCIES = $(gimpbase_def)
+libgimpbase_3_0_la_DEPENDENCIES = $(gimpbase_def)
 
-libgimpbase_2_0_la_LIBADD = $(GLIB_LIBS) $(ole32_lib)
+libgimpbase_3_0_la_LIBADD = $(GLIB_LIBS) $(ole32_lib)
 
 
 install-data-local: install-ms-lib install-libtool-import-lib
diff --git a/libgimpcolor/Makefile.am b/libgimpcolor/Makefile.am
index 5f89ab6..8c4d036 100644
--- a/libgimpcolor/Makefile.am
+++ b/libgimpcolor/Makefile.am
@@ -59,9 +59,9 @@ INCLUDES = \
 EXTRA_DIST = \
 	gimpcolor.def
 
-lib_LTLIBRARIES = libgimpcolor-2.0.la
+lib_LTLIBRARIES = libgimpcolor-3.0.la
 
-libgimpcolor_2_0_la_SOURCES = \
+libgimpcolor_3_0_la_SOURCES = \
 	gimpcolor.h			\
 	gimpcolortypes.h		\
 	gimpadaptivesupersample.c	\
@@ -97,16 +97,16 @@ libgimpcolorinclude_HEADERS = \
 	gimphsv.h			\
 	gimprgb.h
 
-libgimpcolor_2_0_la_LDFLAGS = \
+libgimpcolor_3_0_la_LDFLAGS = \
 	-version-info $(LT_VERSION_INFO)	\
 	$(no_undefined) 			\
 	$(libgimpcolor_export_symbols)
 
-libgimpcolor_2_0_la_DEPENDENCIES = \
+libgimpcolor_3_0_la_DEPENDENCIES = \
 	$(gimpcolor_def)	\
 	$(libgimpbase)
 
-libgimpcolor_2_0_la_LIBADD = \
+libgimpcolor_3_0_la_LIBADD = \
 	$(CAIRO_LIBS)	\
 	$(GLIB_LIBS)	\
 	$(libm)
diff --git a/libgimpconfig/Makefile.am b/libgimpconfig/Makefile.am
index 4f48169..f18f9cc 100644
--- a/libgimpconfig/Makefile.am
+++ b/libgimpconfig/Makefile.am
@@ -56,7 +56,7 @@ INCLUDES = \
 EXTRA_DIST = \
 	gimpconfig.def
 
-lib_LTLIBRARIES = libgimpconfig-2.0.la
+lib_LTLIBRARIES = libgimpconfig-3.0.la
 
 libgimpconfig_sources = 		\
 	gimpconfig.h			\
@@ -85,7 +85,7 @@ libgimpconfig_sources = 		\
 libgimpconfig_built_sources = \
 	gimpcolorconfig-enums.c
 
-libgimpconfig_2_0_la_SOURCES = \
+libgimpconfig_3_0_la_SOURCES = \
 	$(libgimpconfig_sources) $(libgimpconfig_built_sources)
 
 
@@ -105,14 +105,14 @@ libgimpconfiginclude_HEADERS = \
 	gimpcolorconfig-enums.h
 
 
-libgimpconfig_2_0_la_LDFLAGS = \
+libgimpconfig_3_0_la_LDFLAGS = \
 	-version-info $(LT_VERSION_INFO)	\
 	$(no_undefined) 			\
 	$(libgimpconfig_export_symbols)
 
-libgimpconfig_2_0_la_DEPENDENCIES = $(gimpconfig_def)
+libgimpconfig_3_0_la_DEPENDENCIES = $(gimpconfig_def)
 
-libgimpconfig_2_0_la_LIBADD = \
+libgimpconfig_3_0_la_LIBADD = \
 	$(libgimpbase)	\
 	$(libgimpcolor)	\
 	$(libgimpmath)	\
diff --git a/libgimpmath/Makefile.am b/libgimpmath/Makefile.am
index 1201063..bdab920 100644
--- a/libgimpmath/Makefile.am
+++ b/libgimpmath/Makefile.am
@@ -58,9 +58,9 @@ INCLUDES = \
 EXTRA_DIST = \
 	gimpmath.def
 
-lib_LTLIBRARIES = libgimpmath-2.0.la
+lib_LTLIBRARIES = libgimpmath-3.0.la
 
-libgimpmath_2_0_la_SOURCES = \
+libgimpmath_3_0_la_SOURCES = \
 	gimpmath.h	\
 	gimpmathtypes.h	\
 	gimpmatrix.c	\
@@ -77,14 +77,14 @@ libgimpmathinclude_HEADERS = \
 	gimpmd5.h	\
 	gimpvector.h
 
-libgimpmath_2_0_la_LDFLAGS = \
+libgimpmath_3_0_la_LDFLAGS = \
 	-version-info $(LT_VERSION_INFO)	\
 	$(no_undefined)				\
 	$(libgimpmath_export_symbols)
 
-libgimpmath_2_0_la_DEPENDENCIES = $(gimpmath_def) $(libgimpbase)
+libgimpmath_3_0_la_DEPENDENCIES = $(gimpmath_def) $(libgimpbase)
 
-libgimpmath_2_0_la_LIBADD = $(GLIB_LIBS) $(libm)
+libgimpmath_3_0_la_LIBADD = $(GLIB_LIBS) $(libm)
 
 
 install-data-local: install-ms-lib install-libtool-import-lib
diff --git a/libgimpmodule/Makefile.am b/libgimpmodule/Makefile.am
index 9d8dcc4..5e11d62 100644
--- a/libgimpmodule/Makefile.am
+++ b/libgimpmodule/Makefile.am
@@ -54,9 +54,9 @@ INCLUDES = \
 EXTRA_DIST = \
 	gimpmodule.def
 
-lib_LTLIBRARIES = libgimpmodule-2.0.la
+lib_LTLIBRARIES = libgimpmodule-3.0.la
 
-libgimpmodule_2_0_la_SOURCES = \
+libgimpmodule_3_0_la_SOURCES = \
 	gimpmoduletypes.h	\
 	gimpmodule.c		\
 	gimpmodule.h		\
@@ -68,14 +68,14 @@ libgimpmoduleinclude_HEADERS = \
 	gimpmodule.h		\
 	gimpmoduledb.h
 
-libgimpmodule_2_0_la_LDFLAGS = \
+libgimpmodule_3_0_la_LDFLAGS = \
 	-version-info $(LT_VERSION_INFO)	\
 	$(no_undefined) 			\
 	$(libgimpmodule_export_symbols)
 
-libgimpmodule_2_0_la_DEPENDENCIES = $(gimpmodule_def)
+libgimpmodule_3_0_la_DEPENDENCIES = $(gimpmodule_def)
 
-libgimpmodule_2_0_la_LIBADD = \
+libgimpmodule_3_0_la_LIBADD = \
 	$(libgimpbase)			\
 	$(GMODULE_NO_EXPORT_LIBS) 	\
 	$(GLIB_LIBS)
diff --git a/libgimpthumb/Makefile.am b/libgimpthumb/Makefile.am
index 07c157b..04b5625 100644
--- a/libgimpthumb/Makefile.am
+++ b/libgimpthumb/Makefile.am
@@ -52,9 +52,9 @@ INCLUDES = \
 EXTRA_DIST = \
 	gimpthumb.def
 
-lib_LTLIBRARIES = libgimpthumb-2.0.la
+lib_LTLIBRARIES = libgimpthumb-3.0.la
 
-libgimpthumb_2_0_la_SOURCES = \
+libgimpthumb_3_0_la_SOURCES = \
 	gimpthumb.h		\
 	gimpthumb-enums.c	\
 	gimpthumb-enums.h	\
@@ -74,12 +74,12 @@ libgimpthumbinclude_HEADERS = \
 	gimpthumb-utils.h	\
 	gimpthumbnail.h
 
-libgimpthumb_2_0_la_LDFLAGS = \
+libgimpthumb_3_0_la_LDFLAGS = \
 	-version-info $(LT_VERSION_INFO)	\
 	$(no_undefined)				\
 	$(libgimpthumb_export_symbols)
 
-libgimpthumb_2_0_la_LIBADD = $(GDK_PIXBUF_LIBS) $(GLIB_LIBS) 
+libgimpthumb_3_0_la_LIBADD = $(GDK_PIXBUF_LIBS) $(GLIB_LIBS) 
 
 
 noinst_PROGRAMS = gimp-thumbnail-list
diff --git a/libgimpwidgets/Makefile.am b/libgimpwidgets/Makefile.am
index 91f752e..3486fab 100644
--- a/libgimpwidgets/Makefile.am
+++ b/libgimpwidgets/Makefile.am
@@ -57,9 +57,9 @@ INCLUDES = \
 	$(GTK_CFLAGS)	\
 	-I$(includedir)
 
-lib_LTLIBRARIES = libgimpwidgets-2.0.la
+lib_LTLIBRARIES = libgimpwidgets-3.0.la
 
-libgimpwidgets_2_0_la_sources = \
+libgimpwidgets_3_0_la_sources = \
 	gimpbrowser.c			\
 	gimpbrowser.h			\
 	gimpbutton.c			\
@@ -180,17 +180,17 @@ libgimpwidgets_2_0_la_sources = \
 	gimp3migration.c		\
 	gimp3migration.h
 
-libgimpwidgets_2_0_la_built_sources = \
+libgimpwidgets_3_0_la_built_sources = \
 	gimp-wilber-pixbufs.h	\
 	gimpwidgetsenums.c	\
 	gimpwidgetsmarshal.c	\
 	gimpwidgetsmarshal.h
 
-libgimpwidgets_2_0_la_extra_sources = gimpwidgetsmarshal.list
+libgimpwidgets_3_0_la_extra_sources = gimpwidgetsmarshal.list
 
-libgimpwidgets_2_0_la_SOURCES = \
-	$(libgimpwidgets_2_0_la_built_sources)	\
-	$(libgimpwidgets_2_0_la_sources)
+libgimpwidgets_3_0_la_SOURCES = \
+	$(libgimpwidgets_3_0_la_built_sources)	\
+	$(libgimpwidgets_3_0_la_sources)
 
 libgimpwidgetsinclude_HEADERS = \
 	gimpbrowser.h			\
@@ -252,19 +252,19 @@ libgimpwidgetsinclude_HEADERS = \
 	gimpzoommodel.h			\
 	gimp3migration.h
 
-libgimpwidgets_2_0_la_LDFLAGS = \
+libgimpwidgets_3_0_la_LDFLAGS = \
 	-version-info $(LT_VERSION_INFO)\
 	$(no_undefined) 		\
 	$(libgimpwidgets_export_symbols)
 
-libgimpwidgets_2_0_la_LIBADD = \
+libgimpwidgets_3_0_la_LIBADD = \
 	$(libgimpcolor)		\
 	$(libgimpconfig)	\
 	$(libgimpbase)		\
 	$(GTK_LIBS)		\
 	$(libm)
 
-libgimpwidgets_2_0_la_DEPENDENCIES = $(gimpwidgets_def)
+libgimpwidgets_3_0_la_DEPENDENCIES = $(gimpwidgets_def)
 
 
 ## Wilber icons for the window managaer, compiled in
@@ -284,7 +284,7 @@ WILBER_VARIABLES = \
 
 EXTRA_DIST = \
 	gimpwidgets.def				\
-	$(libgimpwidgets_2_0_la_extra_sources)	\
+	$(libgimpwidgets_3_0_la_extra_sources)	\
 	$(WILBER_IMAGES)
 
 
diff --git a/libgimpwidgets/gimp3migration.c b/libgimpwidgets/gimp3migration.c
index a32a2ed..e2d4877 100644
--- a/libgimpwidgets/gimp3migration.c
+++ b/libgimpwidgets/gimp3migration.c
@@ -28,6 +28,8 @@
 #include "gimp3migration.h"
 
 
+#if 0
+
 GtkWidget *
 gtk_box_new (GtkOrientation  orientation,
              gint            spacing)
@@ -85,6 +87,9 @@ gtk_separator_new (GtkOrientation  orientation)
     return gtk_vseparator_new ();
 }
 
+#endif /* if 0 */
+
+
 #if ! GTK_CHECK_VERSION (3, 3, 0)
 
 gboolean
diff --git a/libgimpwidgets/gimp3migration.h b/libgimpwidgets/gimp3migration.h
index 3371c7a..c638587 100644
--- a/libgimpwidgets/gimp3migration.h
+++ b/libgimpwidgets/gimp3migration.h
@@ -33,6 +33,8 @@
  * along. This file will be removed in GIMP 3.
  */
 
+#if 0
+
 GtkWidget * gtk_box_new        (GtkOrientation  orientation,
                                 gint            spacing);
 GtkWidget * gtk_button_box_new (GtkOrientation  orientation);
@@ -43,6 +45,8 @@ GtkWidget * gtk_scrollbar_new  (GtkOrientation  orientation,
                                 GtkAdjustment  *adjustment);
 GtkWidget * gtk_separator_new  (GtkOrientation  orientation);
 
+#endif
+
 
 /* These functions are even more evil. They exist only since GTK+ 3.3
  * and need to be taken care of carefully when building against GTK+
diff --git a/tools/.gitignore b/tools/.gitignore
index 4c7fef5..9ca4384 100644
--- a/tools/.gitignore
+++ b/tools/.gitignore
@@ -3,7 +3,7 @@
 /.deps
 /.libs
 /kernelgen
-/gimptool-2.0
-/gimptool-2.0.exe
+/gimptool-3.0
+/gimptool-3.0.exe
 /test-clipboard
 /test-clipboard.exe
diff --git a/tools/Makefile.am b/tools/Makefile.am
index 6128f57..adb3e8e 100644
--- a/tools/Makefile.am
+++ b/tools/Makefile.am
@@ -8,17 +8,17 @@ endif
 
 SUBDIRS = $(D_pdbgen)
 
-bin_PROGRAMS = gimptool-2.0
+bin_PROGRAMS = gimptool-3.0
 
 noinst_PROGRAMS = test-clipboard
 
 EXTRA_PROGRAMS = \
 	kernelgen
 
-gimptool_2_0_SOURCES = \
+gimptool_3_0_SOURCES = \
 	gimptool.c
 
-gimptool_2_0_LDADD = \
+gimptool_3_0_LDADD = \
 	$(GTK_LIBS)
 
 kernelgen_SOURCES = kernelgen.c



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/libgimpbase/gimpenv.c b/libgimpbase/gimpenv.c
index aa64973..a5f63c0 100644
--- a/libgimpbase/gimpenv.c
+++ b/libgimpbase/gimpenv.c
@@ -135,13 +135,13 @@ gimp_env_init (gboolean plug_in)
  * gimp_directory:
  *
  * Returns the user-specific GIMP settings directory. If the
  * environment variable GIMP2_DIRECTORY exists, it is used. If it is
  * an absolute path, it is used as is.  If it is a relative path, it
  * is taken to be a subdirectory of the home directory. If it is a
  * relative path, and no home directory can be determined, it is taken
  * to be a subdirectory of gimp_data_directory().
  *
  * The usual case is that no GIMP2_DIRECTORY environment variable
  * exists, and then we use the GIMPDIR subdirectory of the home
  * directory. If no home directory exists, we use a per-user
  * subdirectory of gimp_data_directory().  In any case, we always
@@ -164,17 +164,17 @@ gimp_directory (void)
   const gchar  *env_gimp_dir;
   const gchar  *home_dir;
 
-  env_gimp_dir = g_getenv ("GIMP2_DIRECTORY");
+  env_gimp_dir = g_getenv ("GIMP3_DIRECTORY");
 
   if (gimp_dir)
     {
-      gboolean gimp2_directory_changed = FALSE;
+      gboolean gimp3_directory_changed = FALSE;
 
       /* We have constructed the gimp_dir already. We can return
        * gimp_dir unless some parameter gimp_dir depends on has
        * changed. For now we just check for changes to GIMP2_DIRECTORY
        */
-      gimp2_directory_changed =
+      gimp3_directory_changed =
         (env_gimp_dir == NULL &&
          last_env_gimp_dir != NULL) ||
         (env_gimp_dir != NULL &&
@@ -183,7 +183,7 @@ gimp_directory (void)
          last_env_gimp_dir != NULL &&
          strcmp (env_gimp_dir, last_env_gimp_dir) != 0);
 
-      if (! gimp2_directory_changed)
+      if (! gimp3_directory_changed)
         {
           return gimp_dir;
         }
@@ -195,7 +195,7 @@ gimp_directory (void)
         }
     }
 
   /* Remember the GIMP2_DIRECTORY to next invocation so we can check
    * if it changes
    */
   g_free (last_env_gimp_dir);
@@ -348,7 +348,7 @@ gimp_toplevel_directory (void)
  * gimp_data_directory:
  *
  * Returns the top directory for GIMP data. If the environment
  * variable GIMP2_DATADIR exists, that is used.  It should be an
  * absolute pathname.  Otherwise, on Unix the compile-time defined
  * directory is used. On Windows, the installation directory as deduced
  * from the executable's full filename is used.
@@ -369,7 +369,7 @@ gimp_data_directory (void)
     {
       gchar *tmp = _gimp_reloc_find_data_dir (DATADIR);
 
-      gimp_data_dir = gimp_env_get_dir ("GIMP2_DATADIR", tmp);
+      gimp_data_dir = gimp_env_get_dir ("GIMP3_DATADIR", tmp);
       g_free (tmp);
     }
 
@@ -380,7 +380,7 @@ gimp_data_directory (void)
  * gimp_locale_directory:
  *
  * Returns the top directory for GIMP locale files. If the environment
  * variable GIMP2_LOCALEDIR exists, that is used.  It should be an
  * absolute pathname.  Otherwise, on Unix the compile-time defined
  * directory is used. On Windows, the installation directory as deduced
  * from the executable's full filename is used.
@@ -404,7 +404,7 @@ gimp_locale_directory (void)
     {
       gchar *tmp = _gimp_reloc_find_locale_dir (LOCALEDIR);
 
-      gimp_locale_dir = gimp_env_get_dir ("GIMP2_LOCALEDIR", tmp);
+      gimp_locale_dir = gimp_env_get_dir ("GIMP3_LOCALEDIR", tmp);
       g_free (tmp);
 #ifdef G_OS_WIN32
       tmp = g_win32_locale_filename_from_utf8 (gimp_locale_dir);
@@ -420,7 +420,7 @@ gimp_locale_directory (void)
  * gimp_sysconf_directory:
  *
  * Returns the top directory for GIMP config files. If the environment
  * variable GIMP2_SYSCONFDIR exists, that is used.  It should be an
  * absolute pathname.  Otherwise, on Unix the compile-time defined
  * directory is used. On Windows, the installation directory as deduced
  * from the executable's full filename is used.
@@ -441,7 +441,7 @@ gimp_sysconf_directory (void)
     {
       gchar *tmp = _gimp_reloc_find_etc_dir (SYSCONFDIR);
 
-      gimp_sysconf_dir = gimp_env_get_dir ("GIMP2_SYSCONFDIR", tmp);
+      gimp_sysconf_dir = gimp_env_get_dir ("GIMP3_SYSCONFDIR", tmp);
       g_free (tmp);
     }
 
@@ -469,7 +469,7 @@ gimp_user_directory (GimpUserDirectory type)
  * gimp_plug_in_directory:
  *
  * Returns the top directory for GIMP plug_ins and modules. If the
  * environment variable GIMP2_PLUGINDIR exists, that is used.  It
  * should be an absolute pathname. Otherwise, on Unix the compile-time
  * defined directory is used. On Windows, the installation directory as
  * deduced from the executable's full filename is used.
@@ -490,7 +490,7 @@ gimp_plug_in_directory (void)
     {
       gchar *tmp = _gimp_reloc_find_plugin_dir (PLUGINDIR);
 
-      gimp_plug_in_dir = gimp_env_get_dir ("GIMP2_PLUGINDIR", tmp);
+      gimp_plug_in_dir = gimp_env_get_dir ("GIMP3_PLUGINDIR", tmp);
       g_free (tmp);
     }
 
@@ -135,13 +135,13 @@ gimp_env_init (gboolean plug_in)
  *
  * Returns the user-specific GIMP settings directory. If the
- * environment variable GIMP2_DIRECTORY exists, it is used. If it is
+ * environment variable GIMP3_DIRECTORY exists, it is used. If it is
  * an absolute path, it is used as is.  If it is a relative path, it
  * is taken to be a subdirectory of the home directory. If it is a
@@ -135,13 +135,13 @@ gimp_env_init (gboolean plug_in)
  * to be a subdirectory of gimp_data_directory().
  *
- * The usual case is that no GIMP2_DIRECTORY environment variable
+ * The usual case is that no GIMP3_DIRECTORY environment variable
  * exists, and then we use the GIMPDIR subdirectory of the home
  * directory. If no home directory exists, we use a per-user
@@ -164,17 +164,17 @@ gimp_directory (void)
       /* We have constructed the gimp_dir already. We can return
        * gimp_dir unless some parameter gimp_dir depends on has
-       * changed. For now we just check for changes to GIMP2_DIRECTORY
+       * changed. For now we just check for changes to GIMP3_DIRECTORY
        */
@@ -195,7 +195,7 @@ gimp_directory (void)
     }
 
-  /* Remember the GIMP2_DIRECTORY to next invocation so we can check
+  /* Remember the GIMP3_DIRECTORY to next invocation so we can check
    * if it changes
    */
@@ -348,7 +348,7 @@ gimp_toplevel_directory (void)
  *
  * Returns the top directory for GIMP data. If the environment
- * variable GIMP2_DATADIR exists, that is used.  It should be an
+ * variable GIMP3_DATADIR exists, that is used.  It should be an
  * absolute pathname.  Otherwise, on Unix the compile-time defined
  * directory is used. On Windows, the installation directory as deduced
@@ -380,7 +380,7 @@ gimp_data_directory (void)
  *
  * Returns the top directory for GIMP locale files. If the environment
- * variable GIMP2_LOCALEDIR exists, that is used.  It should be an
+ * variable GIMP3_LOCALEDIR exists, that is used.  It should be an
  * absolute pathname.  Otherwise, on Unix the compile-time defined
  * directory is used. On Windows, the installation directory as deduced
@@ -420,7 +420,7 @@ gimp_locale_directory (void)
  *
  * Returns the top directory for GIMP config files. If the environment
- * variable GIMP2_SYSCONFDIR exists, that is used.  It should be an
+ * variable GIMP3_SYSCONFDIR exists, that is used.  It should be an
  * absolute pathname.  Otherwise, on Unix the compile-time defined
  * directory is used. On Windows, the installation directory as deduced
@@ -469,7 +469,7 @@ gimp_user_directory (GimpUserDirectory type)
  *
  * Returns the top directory for GIMP plug_ins and modules. If the
- * environment variable GIMP2_PLUGINDIR exists, that is used.  It
+ * environment variable GIMP3_PLUGINDIR exists, that is used.  It
  * should be an absolute pathname. Otherwise, on Unix the compile-time
  * defined directory is used. On Windows, the installation directory as